@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2013 Sérgio Martins <iamsergio@gmail.com>
+    SPDX-FileCopyrightText: 2013 Sérgio Martins <iamsergio@gmail.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "itiphandlertest.h"
@@ -23,16 +10,16 @@
 #include "fetchjobcalendar.h"
 #include "utils_p.h"
 
-#include <kcalendarcore/icalformat.h>
-#include <kcalendarcore/attendee.h>
+#include <KCalendarCore/ICalFormat>
+#include <KCalendarCore/Attendee>
 #include <itemdeletejob.h>
 #include <collectionfetchjob.h>
 #include <collectionfetchscope.h>
 #include <itemfetchscope.h>
 #include <qtest_akonadi.h>
-#include <mailtransportakonadi/messagequeuejob.h>
+#include <MailTransportAkonadi/MessageQueueJob>
 
-#include <kcalendarcore/event.h>
+#include <KCalendarCore/Event>
 
 #include <QString>
 #include <QTimeZone>
