@@ -1,21 +1,8 @@
 /*
-   Copyright (C) 2011 Sérgio Martins <sergio.martins@kdab.com>
-   Copyright (C) 2012 Sérgio Martins <iamsergio@gmail.com>
+   SPDX-FileCopyrightText: 2011 Sérgio Martins <sergio.martins@kdab.com>
+   SPDX-FileCopyrightText: 2012 Sérgio Martins <iamsergio@gmail.com>
 
-   This library is free software; you can redistribute it and/or modify it
-   under the terms of the GNU Library General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or (at your
-   option) any later version.
-
-   This library is distributed in the hope that it will be useful, but WITHOUT
-   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-   License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-   02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "calendarbase.h"
@@ -189,7 +176,7 @@ void CalendarBasePrivate::collectionFetchResult(KJob *job)
     mCollections.insert(collection.id(), collection);
 
     if (mCollectionJobs.isEmpty()) {
-        emit fetchFinished();
+        Q_EMIT fetchFinished();
     }
 }
 
@@ -252,7 +239,7 @@ void CalendarBasePrivate::slotDeleteFinished(int changeId, const QVector<Akonadi
         }
     }
 
-    emit q->deleteFinished(resultCode == IncidenceChanger::ResultCodeSuccess, errorMessage);
+    Q_EMIT q->deleteFinished(resultCode == IncidenceChanger::ResultCodeSuccess, errorMessage);
 }
 
 void CalendarBasePrivate::slotCreateFinished(int changeId, const Akonadi::Item &item, IncidenceChanger::ResultCode resultCode, const QString &errorMessage)
@@ -267,7 +254,7 @@ void CalendarBasePrivate::slotCreateFinished(int changeId, const Akonadi::Item &
 
     mLastCreationCancelled = (resultCode == IncidenceChanger::ResultCodeUserCanceled);
 
-    emit q->createFinished(resultCode == IncidenceChanger::ResultCodeSuccess, errorMessage);
+    Q_EMIT q->createFinished(resultCode == IncidenceChanger::ResultCodeSuccess, errorMessage);
 }
 
 void CalendarBasePrivate::slotModifyFinished(int changeId, const Akonadi::Item &item, IncidenceChanger::ResultCode resultCode, const QString &errorMessage)
@@ -290,7 +277,7 @@ void CalendarBasePrivate::slotModifyFinished(int changeId, const Akonadi::Item &
             resultCode = IncidenceChanger::ResultCodeAlreadyDeleted;
         }
     }
-    emit q->modifyFinished(resultCode == IncidenceChanger::ResultCodeSuccess, message);
+    Q_EMIT q->modifyFinished(resultCode == IncidenceChanger::ResultCodeSuccess, message);
 }
 
 void CalendarBasePrivate::handleUidChange(const Akonadi::Item &oldItem, const Akonadi::Item &newItem, const QString &newIdentifier)
