@@ -1,20 +1,7 @@
 /*
-  Copyright (c) 2014 Sandro Knauß <knauss@kolabsys.com>
+  SPDX-FileCopyrightText: 2014 Sandro Knauß <knauss@kolabsys.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "calfilterpartstatusproxymodel_p.h"
@@ -24,8 +11,8 @@
 #include <item.h>
 #include <entitytreemodel.h>
 
-#include <kcalendarcore/incidence.h>
-#include <kcalendarcore/attendee.h>
+#include <KCalendarCore/Incidence>
+#include <KCalendarCore/Attendee>
 // #include <email.h>
 
 #include <identitymanager.h>
