@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2011-2013 Sérgio Martins <iamsergio@gmail.com>
+   SPDX-FileCopyrightText: 2011-2013 Sérgio Martins <iamsergio@gmail.com>
 
-   This library is free software; you can redistribute it and/or modify it
-   under the terms of the GNU Library General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or (at your
-   option) any later version.
-
-   This library is distributed in the hope that it will be useful, but WITHOUT
-   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-   License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-   02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "etmcalendar.h"
@@ -137,7 +124,7 @@ void ETMCalendarPrivate::onCollectionChanged(const Akonadi::Collection &collecti
         }
     }
 
-    emit q->collectionChanged(collection, attributeNames);
+    Q_EMIT q->collectionChanged(collection, attributeNames);
 }
 
 void ETMCalendarPrivate::setupFilteredETM()
@@ -296,7 +283,7 @@ void ETMCalendarPrivate::itemsAdded(const Akonadi::Item::List &items)
         if (mPopulatedCollectionIds.contains(id)) {
             // If the collection isn't populated yet, it will be sent later
             // Saves some cpu cycles
-            emit q->calendarChanged();
+            Q_EMIT q->calendarChanged();
         }
     }
 }
@@ -306,7 +293,7 @@ void ETMCalendarPrivate::itemsRemoved(const Akonadi::Item::List &items)
     for (const Akonadi::Item &item : items) {
         internalRemove(item);
     }
-    emit q->calendarChanged();
+    Q_EMIT q->calendarChanged();
 }
 
 Akonadi::Collection ETMCalendarPrivate::collectionFromIndex(const QModelIndex &index)
@@ -324,14 +311,14 @@ void ETMCalendarPrivate::onRowsInserted(const QModelIndex &index, int start, int
     }
 
     if (!collections.isEmpty()) {
-        emit q->collectionsAdded(collections);
+        Q_EMIT q->collectionsAdded(collections);
     }
 }
 
 void ETMCalendarPrivate::onCollectionPopulated(Akonadi::Collection::Id id)
 {
     mPopulatedCollectionIds.insert(id);
-    emit q->calendarChanged();
+    Q_EMIT q->calendarChanged();
 }
 
 void ETMCalendarPrivate::onRowsRemoved(const QModelIndex &index, int start, int end)
@@ -342,7 +329,7 @@ void ETMCalendarPrivate::onRowsRemoved(const QModelIndex &index, int start, int
     }
 
     if (!collections.isEmpty()) {
-        emit q->collectionsRemoved(collections);
+        Q_EMIT q->collectionsRemoved(collections);
     }
 }
 
@@ -398,7 +385,7 @@ void ETMCalendarPrivate::onDataChangedInFilteredModel(const QModelIndex &topLeft
         i = i.sibling(row, topLeft.column());
     }
 
-    emit q->calendarChanged();
+    Q_EMIT q->calendarChanged();
 }
 
 void ETMCalendarPrivate::updateItem(const Akonadi::Item &item)
