@@ -1,21 +1,8 @@
 /*
-   Copyright (C) 2011 Sérgio Martins <sergio.martins@kdab.com>
-   Copyright (C) 2012 Sérgio Martins <iamsergio@gmail.com>
+   SPDX-FileCopyrightText: 2011 Sérgio Martins <sergio.martins@kdab.com>
+   SPDX-FileCopyrightText: 2012 Sérgio Martins <iamsergio@gmail.com>
 
-   This library is free software; you can redistribute it and/or modify it
-   under the terms of the GNU Library General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or (at your
-   option) any later version.
-
-   This library is distributed in the hope that it will be useful, but WITHOUT
-   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-   License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-   02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "fetchjobcalendar.h"
@@ -74,7 +61,7 @@ void FetchJobCalendarPrivate::slotSearchJobFinished(KJob *job)
 void FetchJobCalendarPrivate::slotFetchJobFinished()
 {
     m_isLoaded = true;
-    // emit loadFinished() in a delayed manner, due to freezes because of execs.
+    // Q_EMIT loadFinished() in a delayed manner, due to freezes because of execs.
     QMetaObject::invokeMethod(q, "loadFinished", Qt::QueuedConnection,
                               Q_ARG(bool, m_success), Q_ARG(QString, m_errorMessage));
 }
