@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2011 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
-  Copyright (c) 2004 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2011 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2004 Cornelius Schumacher <schumacher@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "freebusymanager.h"
@@ -30,9 +17,9 @@
 #include <agentmanager.h>
 #include <contactsearchjob.h>
 
-#include <kcalendarcore/event.h>
-#include <kcalendarcore/freebusy.h>
-#include <kcalendarcore/person.h>
+#include <KCalendarCore/Event>
+#include <KCalendarCore/FreeBusy>
+#include <KCalendarCore/Person>
 
 #include "akonadicalendar_debug.h"
 #include <KMessageBox>
@@ -210,7 +197,7 @@ void FreeBusyManagerPrivate::fetchFreeBusyUrl(const QString &email)
             cachedUrl.setUserName(CalendarSettings::self()->freeBusyRetrieveUser());
             cachedUrl.setPassword(CalendarSettings::self()->freeBusyRetrievePassword());
         }
-        emit freeBusyUrlRetrieved(email, replaceVariablesUrl(cachedUrl, email));
+        Q_EMIT freeBusyUrlRetrieved(email, replaceVariablesUrl(cachedUrl, email));
         return;
     }
     // Try with the url configured by preferred email in kcontactmanager
@@ -228,7 +215,7 @@ void FreeBusyManagerPrivate::contactSearchJobFinished(KJob *_job)
     if (_job->error()) {
         qCritical() << "Error while searching for contact: "
                     << _job->errorString() << ", email = " << email;
-        emit freeBusyUrlRetrieved(email, QUrl());
+        Q_EMIT freeBusyUrlRetrieved(email, QUrl());
         return;
     }
 
@@ -246,7 +233,7 @@ void FreeBusyManagerPrivate::contactSearchJobFinished(KJob *_job)
             qCDebug(AKONADICALENDAR_LOG) << "Preferred email of" << email << "is" << pref;
             if (!url.isEmpty()) {
                 qCDebug(AKONADICALENDAR_LOG) << "Taken url from preferred email:" << url;
-                emit freeBusyUrlRetrieved(email, replaceVariablesUrl(QUrl(url), email));
+                Q_EMIT freeBusyUrlRetrieved(email, replaceVariablesUrl(QUrl(url), email));
                 return;
             }
         }
@@ -255,7 +242,7 @@ void FreeBusyManagerPrivate::contactSearchJobFinished(KJob *_job)
     if (!CalendarSettings::self()->freeBusyRetrieveAuto()) {
         // No, so no FB list here
         qCDebug(AKONADICALENDAR_LOG) << "No automatic retrieving";
-        emit freeBusyUrlRetrieved(email, QUrl());
+        Q_EMIT freeBusyUrlRetrieved(email, QUrl());
         return;
     }
 
@@ -264,7 +251,7 @@ void FreeBusyManagerPrivate::contactSearchJobFinished(KJob *_job)
     int emailpos = email.indexOf(QLatin1Char('@'));
     if (emailpos == -1) {
         qCWarning(AKONADICALENDAR_LOG) << "No '@' found in" << email;
-        emit freeBusyUrlRetrieved(email, QUrl());
+        Q_EMIT freeBusyUrlRetrieved(email, QUrl());
         return;
     }
 
@@ -280,7 +267,7 @@ void FreeBusyManagerPrivate::contactSearchJobFinished(KJob *_job)
             && !emailHost.endsWith(QLatin1Char('.') + hostDomain)) {
             // Host names do not match
             qCDebug(AKONADICALENDAR_LOG) << "Host '" << hostDomain << "' doesn't match email '" << email << '\'';
-            emit freeBusyUrlRetrieved(email, QUrl());
+            Q_EMIT freeBusyUrlRetrieved(email, QUrl());
             return;
         }
     }
@@ -298,7 +285,7 @@ void FreeBusyManagerPrivate::contactSearchJobFinished(KJob *_job)
         // no need to cache this URL as this is pretty fast to get from the config value.
         // return the fullpath URL
         qCDebug(AKONADICALENDAR_LOG) << "Found url. email=" << email << "; url=" << fullpathURL;
-        emit freeBusyUrlRetrieved(email, fullpathURL);
+        Q_EMIT freeBusyUrlRetrieved(email, fullpathURL);
         return;
     }
 
@@ -347,10 +334,10 @@ void FreeBusyManagerPrivate::fbCheckerJobFinished(KJob *job)
         KConfigGroup group = cfg.group(email);
         group.writeEntry("url", dirURL.toDisplayString());   // prettyURL() does not write user nor password
         qCDebug(AKONADICALENDAR_LOG) << "Found url email=" << email << "; url=" << dirURL;
-        emit freeBusyUrlRetrieved(email, dirURL);
+        Q_EMIT freeBusyUrlRetrieved(email, dirURL);
     } else {
         qCDebug(AKONADICALENDAR_LOG) << "Returning invalid url";
-        emit freeBusyUrlRetrieved(email, QUrl());
+        Q_EMIT freeBusyUrlRetrieved(email, QUrl());
     }
 }
 
@@ -418,7 +405,7 @@ void FreeBusyManagerPrivate::processFreeBusyDownloadResult(KJob *_job)
             fb->setOrganizer(p);
             q->saveFreeBusy(fb, p);
             qCDebug(AKONADICALENDAR_LOG) << "Freebusy retrieved for " << email;
-            emit q->freeBusyRetrieved(fb, email);
+            Q_EMIT q->freeBusyRetrieved(fb, email);
         } else {
             qCritical() << "Error downloading freebusy, invalid fb.";
             KMessageBox::sorry(
@@ -700,7 +687,7 @@ void FreeBusyManagerPrivate::onFreeBusyRetrieved(const QString &email, const QSt
         if (queue->mHandlersCount == 0) {
             fetchFreeBusyUrl(email);
         } else {
-            emit q->freeBusyRetrieved(queue->mResultingFreeBusy, email);
+            Q_EMIT q->freeBusyRetrieved(queue->mResultingFreeBusy, email);
         }
         mProvidersRequestsByEmail.remove(email);
     }
@@ -923,7 +910,7 @@ bool FreeBusyManager::retrieveFreeBusy(const QString &email, bool forceDownload,
     if (Akonadi::CalendarUtils::thatIsMe(email)) {
         // Don't download our own free-busy list from the net
         qCDebug(AKONADICALENDAR_LOG) << "freebusy of owner, not downloading";
-        emit freeBusyRetrieved(d->ownerFreeBusy(), email);
+        Q_EMIT freeBusyRetrieved(d->ownerFreeBusy(), email);
         return true;
     }
 
@@ -931,7 +918,7 @@ bool FreeBusyManager::retrieveFreeBusy(const QString &email, bool forceDownload,
     KCalendarCore::FreeBusy::Ptr fb = loadFreeBusy(email);
     if (fb) {
         qCDebug(AKONADICALENDAR_LOG) << "Found a cached copy for " << email;
-        emit freeBusyRetrieved(fb, email);
+        Q_EMIT freeBusyRetrieved(fb, email);
         return true;
     }
 
@@ -945,7 +932,7 @@ bool FreeBusyManager::retrieveFreeBusy(const QString &email, bool forceDownload,
 
     if (d->mRetrieveQueue.count() > 1) {
         // TODO: true should always emit
-        qCWarning(AKONADICALENDAR_LOG) << "Returning true without emit, is this correct?";
+        qCWarning(AKONADICALENDAR_LOG) << "Returning true without Q_EMIT, is this correct?";
         return true;
     }
 
