@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2002-2004 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
-  Copyright (c) 2004 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2002-2004 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2004 Cornelius Schumacher <schumacher@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef AKONADI_FREEBUSYMANAGER_P_H
@@ -24,8 +11,8 @@
 #include "etmcalendar.h"
 #include "mailscheduler_p.h"
 
-#include <kcalendarcore/freebusy.h>
-#include <kcalendarcore/icalformat.h>
+#include <KCalendarCore/FreeBusy>
+#include <KCalendarCore/ICalFormat>
 
 #include <QPointer>
 #include <QDBusInterface>
