@@ -1,26 +1,13 @@
 /*
-  Copyright (C) 2010-2012 Sérgio Martins <iamsergio@gmail.com>
+  SPDX-FileCopyrightText: 2010-2012 Sérgio Martins <iamsergio@gmail.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "history.h"
 #include "history_p.h"
 #include "akonadicalendar_debug.h"
-#include <kcalutils/stringify.h>
+#include <KCalUtils/Stringify>
 
 using namespace KCalendarCore;
 using namespace Akonadi;
@@ -151,7 +138,7 @@ bool History::clear()
     } else {
         result = false;
     }
-    emit changed();
+    Q_EMIT changed();
     return result;
 }
 
@@ -186,7 +173,7 @@ void History::Private::updateIds(Item::Id oldId, Item::Id newId)
 void History::Private::doIt(OperationType type)
 {
     mOperationTypeInProgress = type;
-    emit q->changed(); // Application will disable undo/redo buttons because operation is in progress
+    Q_EMIT q->changed(); // Application will disable undo/redo buttons because operation is in progress
     Q_ASSERT(!stack().isEmpty());
     mEntryInProgress = stack().pop();
 
@@ -226,7 +213,7 @@ void History::Private::handleFinished(IncidenceChanger::ResultCode changerResult
 
     emitDone(mOperationTypeInProgress, resultCode);
     mOperationTypeInProgress = TypeNone;
-    emit q->changed();
+    Q_EMIT q->changed();
 }
 
 void History::Private::stackEntry(const Entry::Ptr &entry, uint atomicOperationId)
@@ -264,7 +251,7 @@ void History::Private::stackEntry(const Entry::Ptr &entry, uint atomicOperationI
             mUndoStack.push(entryToPush);
         }
         mRedoStack.clear();
-        emit q->changed();
+        Q_EMIT q->changed();
     } else {
         if (entryToPush) {
             mQueuedEntries.append(entryToPush);
@@ -324,9 +311,9 @@ QStack<Entry::Ptr> &History::Private::destinationStack()
 void History::Private::emitDone(OperationType type, History::ResultCode resultCode)
 {
     if (type == TypeUndo) {
-        emit q->undone(resultCode);
+        Q_EMIT q->undone(resultCode);
     } else if (type == TypeRedo) {
-        emit q->redone(resultCode);
+        Q_EMIT q->redone(resultCode);
     } else {
         Q_ASSERT(false);
     }
