@@ -1,25 +1,12 @@
 /*
-  Copyright (C) 2010-2012 Sérgio Martins <iamsergio@gmail.com>
+  SPDX-FileCopyrightText: 2010-2012 Sérgio Martins <iamsergio@gmail.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "history_p.h"
 #include "akonadicalendar_debug.h"
-#include <kcalutils/stringify.h>
+#include <KCalUtils/Stringify>
 #include <KLocalizedString>
 
 Entry::Entry(const Akonadi::Item &item, const QString &description, History *qq)
@@ -81,7 +68,7 @@ void Entry::doIt(OperationType type)
     }
 
     if (!result) {
-        emit finished(IncidenceChanger::ResultCodeJobError, i18n("General error"));
+        Q_EMIT finished(IncidenceChanger::ResultCodeJobError, i18n("General error"));
     }
 }
 
@@ -90,7 +77,7 @@ CreationEntry::CreationEntry(const Akonadi::Item &item, const QString &descripti
 {
     mLatestRevisionByItemId.insert(item.id(), item.revision());
     Q_ASSERT(mItems.count() == 1);
-    const Incidence::Ptr incidence = mItems.first().payload<KCalendarCore::Incidence::Ptr>();
+    const Incidence::Ptr incidence = mItems.constFirst().payload<KCalendarCore::Incidence::Ptr>();
     if (mDescription.isEmpty()) {
         mDescription = i18nc("%1 is event, todo or journal", "%1 creation",
                              KCalUtils::Stringify::incidenceType(incidence->type()));
@@ -101,7 +88,7 @@ CreationEntry::CreationEntry(const Akonadi::Item &item, const QString &descripti
 
 bool CreationEntry::undo()
 {
-    const int changeId = mChanger->deleteIncidence(mItems.first(), currentParent());
+    const int changeId = mChanger->deleteIncidence(mItems.constFirst(), currentParent());
     mChangeIds << changeId;
 
     if (changeId == -1) {
@@ -113,7 +100,7 @@ bool CreationEntry::undo()
 
 bool CreationEntry::redo()
 {
-    Akonadi::Item item = mItems.first();
+    const Akonadi::Item item = mItems.constFirst();
     Q_ASSERT(item.hasPayload<KCalendarCore::Incidence::Ptr>());
     const int changeId = mChanger->createIncidence(item.payload<KCalendarCore::Incidence::Ptr>(),
                                                    Collection(item.storageCollectionId()),
@@ -132,9 +119,9 @@ void CreationEntry::onDeleteFinished(int changeId, const QVector<Akonadi::Item::
     if (mChangeIds.contains(changeId)) {
         if (resultCode == IncidenceChanger::ResultCodeSuccess) {
             Q_ASSERT(deletedIds.count() == 1);
-            mLatestRevisionByItemId.remove(deletedIds.first());   // TODO
+            mLatestRevisionByItemId.remove(deletedIds.constFirst());   // TODO
         }
-        emit finished(resultCode, errorString);
+        Q_EMIT finished(resultCode, errorString);
     }
 }
 
@@ -145,20 +132,20 @@ void CreationEntry::onCreateFinished(int changeId, const Akonadi::Item &item, Ak
             mLatestRevisionByItemId.insert(item.id(), item.revision());
             Q_ASSERT(mItems.count() == 1);
 
-            if (mItems.first().id() == item.id()) {
-                qCWarning(AKONADICALENDAR_LOG) << "Duplicate id. Old= " << mItems.first().id() << item.id();
+            if (mItems.constFirst().id() == item.id()) {
+                qCWarning(AKONADICALENDAR_LOG) << "Duplicate id. Old= " << mItems.constFirst().id() << item.id();
                 Q_ASSERT(false);
             }
-            updateIdsGlobaly(mItems.first().id(), item.id());
+            updateIdsGlobaly(mItems.constFirst().id(), item.id());
         }
-        emit finished(resultCode, errorString);
+        Q_EMIT finished(resultCode, errorString);
     }
 }
 
 DeletionEntry::DeletionEntry(const Akonadi::Item::List &items, const QString &description, History *q)
     : Entry(items, description, q)
 {
-    const Incidence::Ptr incidence = items.first().payload<KCalendarCore::Incidence::Ptr>();
+    const Incidence::Ptr incidence = items.constFirst().payload<KCalendarCore::Incidence::Ptr>();
     if (mDescription.isEmpty()) {
         mDescription = i18nc("%1 is event, todo or journal", "%1 deletion",
                              KCalUtils::Stringify::incidenceType(incidence->type()));
@@ -214,7 +201,7 @@ void DeletionEntry::onDeleteFinished(int changeId, const QVector<Akonadi::Item::
                 mLatestRevisionByItemId.remove(id);    // TODO
             }
         }
-        emit finished(resultCode, errorString);
+        Q_EMIT finished(resultCode, errorString);
     }
 }
 
@@ -231,7 +218,7 @@ void DeletionEntry::onCreateFinished(int changeId, const Akonadi::Item &item, Ak
         --mNumPendingCreations;
         mOldIdByChangeId.remove(changeId);
         if (mNumPendingCreations == 0) {
-            emit finished(mResultCode, mErrorString);
+            Q_EMIT finished(mResultCode, mErrorString);
         }
     }
 }
@@ -240,7 +227,7 @@ ModificationEntry::ModificationEntry(const Akonadi::Item &item, const Incidence:
     : Entry(item, description, q)
     , mOriginalPayload(originalPayload->clone())
 {
-    const Incidence::Ptr incidence = mItems.first().payload<KCalendarCore::Incidence::Ptr>();
+    const Incidence::Ptr incidence = mItems.constFirst().payload<KCalendarCore::Incidence::Ptr>();
     if (mDescription.isEmpty()) {
         mDescription = i18nc("%1 is event, todo or journal", "%1 modification",
                              KCalUtils::Stringify::incidenceType(incidence->type()));
@@ -251,7 +238,7 @@ ModificationEntry::ModificationEntry(const Akonadi::Item &item, const Incidence:
 
 bool ModificationEntry::undo()
 {
-    Item oldItem = mItems.first();
+    Item oldItem = mItems.constFirst();
     oldItem.setPayload<KCalendarCore::Incidence::Ptr>(mOriginalPayload);
     const int changeId = mChanger->modifyIncidence(oldItem, Incidence::Ptr(), currentParent());
     mChangeIds << changeId;
@@ -265,7 +252,7 @@ bool ModificationEntry::undo()
 
 bool ModificationEntry::redo()
 {
-    const int changeId = mChanger->modifyIncidence(mItems.first(), mOriginalPayload,
+    const int changeId = mChanger->modifyIncidence(mItems.constFirst(), mOriginalPayload,
                                                    currentParent());
     mChangeIds << changeId;
 
@@ -282,7 +269,7 @@ void ModificationEntry::onModifyFinished(int changeId, const Akonadi::Item &item
         if (resultCode == IncidenceChanger::ResultCodeSuccess) {
             mLatestRevisionByItemId.insert(item.id(), item.revision());
         }
-        emit finished(resultCode, errorString);
+        Q_EMIT finished(resultCode, errorString);
     }
 }
 
@@ -349,6 +336,6 @@ void MultiEntry::onEntryFinished(Akonadi::IncidenceChanger::ResultCode resultCod
             && resultCode != IncidenceChanger::ResultCodeSuccess)) {
         mFinishedEntries = mEntries.count(); // we're done
         mOperationInProgress = TypeNone;
-        emit finished(resultCode, errorString);
+        Q_EMIT finished(resultCode, errorString);
     }
 }
