@@ -1,22 +1,9 @@
 /**
   This file is part of the akonadi-calendar library.
 
-  Copyright (C) 2013 Sérgio Martins <iamsergio@gmail.com>
+  SPDX-FileCopyrightText: 2013 Sérgio Martins <iamsergio@gmail.com>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "icalimporter.h"
@@ -40,12 +27,9 @@ using namespace KCalendarCore;
 using namespace Akonadi;
 
 ICalImporter::Private::Private(IncidenceChanger *changer, ICalImporter *qq)
-    : QObject()
+    : QObject(qq)
     , q(qq)
     , m_changer(changer)
-    , m_numIncidences(0)
-    , m_working(false)
-    , m_temporaryFile(nullptr)
 {
     if (!changer) {
         m_changer = new IncidenceChanger(q);
@@ -73,10 +57,10 @@ void ICalImporter::Private::onIncidenceCreated(int changeId, const Akonadi::Item
         m_working = false;
         setErrorMessage(errorString);
         m_pendingRequests.clear();
-        emit q->importIntoExistingFinished(false, m_numIncidences);
+        Q_EMIT q->importIntoExistingFinished(false, m_numIncidences);
     } else if (m_pendingRequests.isEmpty()) {
         m_working = false;
-        emit q->importIntoExistingFinished(true, m_numIncidences);
+        Q_EMIT q->importIntoExistingFinished(true, m_numIncidences);
     }
 }
 
@@ -95,7 +79,7 @@ void ICalImporter::Private::resourceCreated(KJob *job)
     m_working = false;
     if (createjob->error()) {
         setErrorMessage(i18n("Error creating ical resource: %1", createjob->errorString()));
-        emit q->importIntoNewFinished(false);
+        Q_EMIT q->importIntoNewFinished(false);
         return;
     }
 
@@ -107,7 +91,7 @@ void ICalImporter::Private::resourceCreated(KJob *job)
     QDBusInterface iface(service, QStringLiteral("/Settings"));
     if (!iface.isValid()) {
         setErrorMessage(i18n("Failed to obtain D-Bus interface for remote configuration."));
-        emit q->importIntoNewFinished(false);
+        Q_EMIT q->importIntoNewFinished(false);
         return;
     }
 
@@ -117,7 +101,7 @@ void ICalImporter::Private::resourceCreated(KJob *job)
     iface.call(QStringLiteral("setPath"), path);
     instance.reconfigure();
 
-    emit q->importIntoNewFinished(true);
+    Q_EMIT q->importIntoNewFinished(true);
 }
 
 void ICalImporter::Private::remoteDownloadFinished(KIO::Job *job, const QByteArray &data)
@@ -131,7 +115,7 @@ void ICalImporter::Private::remoteDownloadFinished(KIO::Job *job, const QByteArr
         q->importIntoExistingResource(QUrl(m_temporaryFile->fileName()), m_collection);
     } else {
         setErrorMessage(i18n("Could not download remote file."));
-        emit q->importIntoExistingFinished(false, 0);
+        Q_EMIT q->importIntoExistingFinished(false, 0);
     }
 }
 
@@ -141,6 +125,10 @@ ICalImporter::ICalImporter(Akonadi::IncidenceChanger *changer, QObject *parent)
 {
 }
 
+ICalImporter::~ICalImporter()
+{
+}
+
 QString ICalImporter::errorMessage() const
 {
     return d->m_lastErrorMessage;
