@@ -1,21 +1,8 @@
 /*
-  Copyright (C) 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (C) 2010-2012 Sérgio Martins <iamsergio@gmail.com>
+  SPDX-FileCopyrightText: 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2010-2012 Sérgio Martins <iamsergio@gmail.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "incidencechanger.h"
 #include "incidencechanger_p.h"
@@ -425,7 +412,7 @@ void IncidenceChanger::Private::handleModifyJobResult(KJob *job)
         change->newItem = item;
         if (change->recordToHistory && !change->originalItems.isEmpty()) {
             Q_ASSERT(change->originalItems.count() == 1);
-            mHistory->recordModification(change->originalItems.first(), item,
+            mHistory->recordModification(change->originalItems.constFirst(), item,
                                          description, change->atomicOperationId);
         }
 
@@ -1128,6 +1115,16 @@ IncidenceChanger::DestinationPolicy IncidenceChanger::destinationPolicy() const
     return d->mDestinationPolicy;
 }
 
+void IncidenceChanger::setEntityTreeModel(Akonadi::EntityTreeModel *entityTreeModel)
+{
+    d->mEntityTreeModel = entityTreeModel;
+}
+
+Akonadi::EntityTreeModel *IncidenceChanger::entityTreeModel() const
+{
+    return d->mEntityTreeModel;
+}
+
 void IncidenceChanger::setDefaultCollection(const Akonadi::Collection &collection)
 {
     d->mDefaultCollection = collection;
