@@ -1,21 +1,8 @@
 /*
-  Copyright (C) 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (C) 2010-2012 Sérgio Martins <iamsergio@gmail.com>
+  SPDX-FileCopyrightText: 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2010-2012 Sérgio Martins <iamsergio@gmail.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef AKONADI_INCIDENCECHANGER_H
 #define AKONADI_INCIDENCECHANGER_H
@@ -26,11 +13,12 @@
 #include <collection.h>
 #include "itiphandler.h"
 
-#include <kcalendarcore/incidence.h>
+#include <KCalendarCore/Incidence>
 
 #include <QWidget>
 
 namespace Akonadi {
+class EntityTreeModel;
 /**
  * @short IncidenceChanger is the preferred way to easily create, modify and delete incidences.
  *
@@ -241,6 +229,17 @@ public:
       */
     void endAtomicOperation();
 
+    /**
+     * Sets the base ETM tree model
+     * Used by the editor dialog's collection combobox, for instance.
+     */
+    void setEntityTreeModel(Akonadi::EntityTreeModel *model);
+
+    /**
+     * Returns the base ETM tree model
+     */
+    Akonadi::EntityTreeModel *entityTreeModel() const;
+
     /**
       * Sets the default collection.
       * @param collection The collection to be used in createIncidence() if the
