@@ -1,25 +1,12 @@
 /*
-  Copyright (C) 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Author: Sergio Martins, <sergio.martins@kdab.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
+  SPDX-FileContributor: Sergio Martins <sergio.martins@kdab.com>
 
-  Copyright (C) 2010-2012 Sérgio Martins <iamsergio@gmail.com>
+  SPDX-FileCopyrightText: 2010-2012 Sérgio Martins <iamsergio@gmail.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef AKONADI_INCIDENCECHANGER_P_H
 #define AKONADI_INCIDENCECHANGER_P_H
@@ -314,6 +301,7 @@ public:
     QHash<const KJob *, Change::Ptr> mChangeForJob;
     bool mShowDialogsOnError = false;
     Akonadi::Collection mDefaultCollection;
+    Akonadi::EntityTreeModel *mEntityTreeModel = nullptr;
     DestinationPolicy mDestinationPolicy;
     QVector<Akonadi::Item::Id> mDeletedItemIds;
     Change::List mPendingCreations; // Creations waiting for collections to be loaded
