@@ -1,26 +1,13 @@
 /*
-  Copyright (c) 2002-2004 Klarälvdalens Datakonsult AB
+  SPDX-FileCopyrightText: 2002-2004 Klarälvdalens Datakonsult AB,
         <info@klaralvdalens-datakonsult.se>
 
-  Copyright (C) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (C) 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  Copyright (C) 2012 Sérgio Martins <iamsergio@gmail.com>
+  SPDX-FileCopyrightText: 2012 Sérgio Martins <iamsergio@gmail.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "itiphandler.h"
@@ -31,15 +18,15 @@
 #include "utils_p.h"
 #include "mailclient_p.h"
 
-#include <kcalendarcore/icalformat.h>
-#include <kcalendarcore/incidence.h>
-#include <kcalendarcore/schedulemessage.h>
-#include <kcalendarcore/attendee.h>
-#include <kcalutils/stringify.h>
+#include <KCalendarCore/ICalFormat>
+#include <KCalendarCore/Incidence>
+#include <KCalendarCore/ScheduleMessage>
+#include <KCalendarCore/Attendee>
+#include <KCalUtils/Stringify>
 
 #include <identitymanager.h>
-#include <mailtransportakonadi/messagequeuejob.h>
-#include <mailtransport/transportmanager.h>
+#include <MailTransportAkonadi/MessageQueueJob>
+#include <MailTransport/TransportManager>
 
 #include <KMessageBox>
 #include <KLocalizedString>
@@ -342,7 +329,7 @@ void ITIPHandler::publishInformation(const KCalendarCore::Incidence::Ptr &incide
         d->m_scheduler->publish(incidence, publishdlg->addresses());
     } else {
         d->m_currentOperation = OperationNone;
-        emit informationPublished(ResultSuccess, QString());    // Canceled.
+        Q_EMIT informationPublished(ResultSuccess, QString());    // Canceled.
     }
     delete publishdlg;
 }
