@@ -1,25 +1,12 @@
 /*
-  Copyright (C) 2012 Sérgio Martins <iamsergio@gmail.com>
+  SPDX-FileCopyrightText: 2012 Sérgio Martins <iamsergio@gmail.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "itiphandler_p.h"
 #include "fetchjobcalendar.h"
-#include <kcalendarcore/incidence.h>
+#include <KCalendarCore/Incidence>
 #include <KMessageBox>
 #include <KLocalizedString>
 #include "akonadicalendar_debug.h"
@@ -77,7 +64,7 @@ void ITIPHandler::Private::onHelperFinished(Akonadi::ITIPHandlerHelper::SendResu
         MailScheduler::Result result2 = success ? MailScheduler::ResultSuccess : MailScheduler::ResultGenericError;
         finishProcessiTIPMessage(result2, i18n("Error: %1", errorMessage));
     } else {
-        emit q->iTipMessageSent(success ? ResultSuccess : ResultError,
+        Q_EMIT q->iTipMessageSent(success ? ResultSuccess : ResultError,
                                 success ? QString() : i18n("Error: %1", errorMessage));
     }
 }
@@ -100,7 +87,7 @@ void ITIPHandler::Private::onLoadFinished(bool success, const QString &errorMess
                                   m_queuedInvitation.iCal,
                                   m_queuedInvitation.action);
         } else {
-            emit q->iTipMessageProcessed(ResultError, i18n("Error loading calendar: %1", errorMessage));
+            Q_EMIT q->iTipMessageProcessed(ResultError, i18n("Error loading calendar: %1", errorMessage));
         }
     } else if (m_currentOperation == OperationSendiTIPMessage) {
         q->sendiTIPMessage(m_queuedInvitation.method,
@@ -115,7 +102,7 @@ void ITIPHandler::Private::finishProcessiTIPMessage(Akonadi::MailScheduler::Resu
 {
     // Handle when user cancels on the collection selection dialog
     if (result == MailScheduler::ResultUserCancelled) {
-        emit q->iTipMessageProcessed(ResultCancelled, QString());
+        Q_EMIT q->iTipMessageProcessed(ResultCancelled, QString());
         return;
     }
 
@@ -138,7 +125,7 @@ void ITIPHandler::Private::finishProcessiTIPMessage(Akonadi::MailScheduler::Resu
         }
     }
 
-    emit q->iTipMessageProcessed(success ? ResultSuccess : ResultError,
+    Q_EMIT q->iTipMessageProcessed(success ? ResultSuccess : ResultError,
                                  success ? QString() : i18n("Error: %1", errorMessage));
 }
 
@@ -146,7 +133,7 @@ void ITIPHandler::Private::onHelperModifyDialogClosed(ITIPHandlerHelper::SendRes
 {
     if (sendResult == ITIPHandlerHelper::ResultNoSendingNeeded
         || sendResult == ITIPHandlerHelper::ResultCanceled) {
-        emit q->iTipMessageSent(ResultSuccess, QString());
+        Q_EMIT q->iTipMessageSent(ResultSuccess, QString());
     }
 }
 
@@ -162,7 +149,7 @@ void ITIPHandler::Private::finishSendiTIPMessage(Akonadi::MailScheduler::Result
                                      i18n("Sending Free/Busy"),
                                      QStringLiteral("FreeBusyPublishSuccess"));
         }
-        emit q->iTipMessageSent(ITIPHandler::ResultSuccess, QString());
+        Q_EMIT q->iTipMessageSent(ITIPHandler::ResultSuccess, QString());
     } else {
         const QString error = i18nc("Groupware message sending failed. "
                                     "%2 is request/reply/add/cancel/counter/etc.",
@@ -173,7 +160,7 @@ void ITIPHandler::Private::finishSendiTIPMessage(Akonadi::MailScheduler::Result
             KMessageBox::error(m_parentWidget, error);
         }
         qCritical() << "Groupware message sending failed." << error << errorMessage;
-        emit q->iTipMessageSent(ITIPHandler::ResultError, error + errorMessage);
+        Q_EMIT q->iTipMessageSent(ITIPHandler::ResultError, error + errorMessage);
     }
 }
 
@@ -186,7 +173,7 @@ void ITIPHandler::Private::finishPublishInformation(Akonadi::MailScheduler::Resu
                                      i18n("Publishing"),
                                      QStringLiteral("IncidencePublishSuccess"));
         }
-        emit q->informationPublished(ITIPHandler::ResultSuccess, QString());
+        Q_EMIT q->informationPublished(ITIPHandler::ResultSuccess, QString());
     } else {
         const QString error = i18n("Unable to publish the item '%1'",
                                    m_queuedInvitation.incidence->summary());
@@ -194,7 +181,7 @@ void ITIPHandler::Private::finishPublishInformation(Akonadi::MailScheduler::Resu
             KMessageBox::error(m_parentWidget, error);
         }
         qCritical() << "Publish failed." << error << errorMessage;
-        emit q->informationPublished(ITIPHandler::ResultError, error + errorMessage);
+        Q_EMIT q->informationPublished(ITIPHandler::ResultError, error + errorMessage);
     }
 }
 
@@ -207,7 +194,7 @@ void ITIPHandler::Private::finishSendAsICalendar(Akonadi::MailClient::Result res
                                      i18n("Forwarding"),
                                      QStringLiteral("IncidenceForwardSuccess"));
         }
-        emit q->sentAsICalendar(ITIPHandler::ResultSuccess, QString());
+        Q_EMIT q->sentAsICalendar(ITIPHandler::ResultSuccess, QString());
     } else {
         if (m_parentWidget) {
             KMessageBox::error(m_parentWidget,
@@ -216,7 +203,7 @@ void ITIPHandler::Private::finishSendAsICalendar(Akonadi::MailClient::Result res
                                i18n("Forwarding Error"));
         }
         qCritical() << "Sent as iCalendar failed." << errorMessage;
-        emit q->sentAsICalendar(ITIPHandler::ResultError, errorMessage);
+        Q_EMIT q->sentAsICalendar(ITIPHandler::ResultError, errorMessage);
     }
 
     sender()->deleteLater(); // Delete the mailer
