@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2001,2004 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (c) 2010,2012 Sérgio Martins <iamsergio@gmail.com>
+  SPDX-FileCopyrightText: 2001, 2004 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2010, 2012 Sérgio Martins <iamsergio@gmail.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef AKONADI_CALENDAR_MAILSCHEDULER_P_H
 #define AKONADI_CALENDAR_MAILSCHEDULER_P_H
@@ -23,7 +10,7 @@
 #include "scheduler_p.h"
 #include "mailclient_p.h"
 
-#include <kcalendarcore/incidence.h>
+#include <KCalendarCore/Incidence>
 #include <item.h>
 
 namespace Akonadi {
