@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (c) 2009 Allen Winter <winter@kde.org>
+  SPDX-FileCopyrightText: 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2009 Allen Winter <winter@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "publishdialog_p.h"
@@ -23,7 +10,7 @@
 #include <Akonadi/Contact/EmailAddressSelectionDialog>
 #include <Akonadi/Contact/AbstractEmailAddressSelectionDialog>
 #include <KEmailAddress>
-#include <kcalendarcore/person.h>
+#include <KCalendarCore/Person>
 
 #include <KLocalizedString>
 #include <KPluginFactory>
