@@ -1,22 +1,9 @@
 /*
- *  Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
- *  Copyright (C) 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
- *  Copyright (C) 2009 - 2010 Tobias Koenig <tokoe@kde.org>
+ *  SPDX-FileCopyrightText: 2010 Casey Link <unnamedrambler@gmail.com>
+ *  SPDX-FileCopyrightText: 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+ *  SPDX-FileCopyrightText: 2009-2010 Tobias Koenig <tokoe@kde.org>
  *
- *  This library is free software; you can redistribute it and/or modify it
- *  under the terms of the GNU Library General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or (at your
- *  option) any later version.
- *
- *  This library is distributed in the hope that it will be useful, but WITHOUT
- *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- *  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
- *  License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to the
- *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- *  02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "standardcalendaractionmanager.h"
@@ -25,8 +12,8 @@
 
 #include <QAction>
 #include <KActionCollection>
-#include <kcalendarcore/event.h>
-#include <kcalendarcore/journal.h>
+#include <KCalendarCore/Event>
+#include <KCalendarCore/Journal>
 #include <kcalendarcore/todo.h>
 #include <KLocalizedString>
 
@@ -61,12 +48,12 @@ public:
         switch (type) {
         case Akonadi::StandardActionManager::CreateCollection:
             mGenericManager->action(Akonadi::StandardActionManager::CreateCollection)->setText(
-                i18n("Add Calendar Folder..."));
+                i18n("Add Folder..."));
             mGenericManager->action(Akonadi::StandardActionManager::CreateCollection)->setWhatsThis(
                 i18n("Add a new calendar folder to the currently selected calendar folder."));
             mGenericManager->setContextText(
                 StandardActionManager::CreateCollection, StandardActionManager::DialogTitle,
-                i18nc("@title:window", "New Calendar Folder"));
+                i18nc("@title:window", "New Folder"));
 
             mGenericManager->setContextText(
                 StandardActionManager::CreateCollection, StandardActionManager::ErrorMessageText,
@@ -84,13 +71,13 @@ public:
             break;
         case  Akonadi::StandardActionManager::CopyCollections:
             mGenericManager->setActionText(Akonadi::StandardActionManager::CopyCollections,
-                                           ki18np("Copy Calendar Folder", "Copy %1 Calendar Folders"));
+                                           ki18np("Copy Folder", "Copy %1 Folders"));
             mGenericManager->action(Akonadi::StandardActionManager::CopyCollections)->setWhatsThis(
                 i18n("Copy the selected calendar folders to the clipboard."));
             break;
         case Akonadi::StandardActionManager::DeleteCollections:
             mGenericManager->setActionText(Akonadi::StandardActionManager::DeleteCollections,
-                                           ki18np("Delete Calendar Folder", "Delete %1 Calendar Folders"));
+                                           ki18np("Delete Folder", "Delete %1 Folders"));
             mGenericManager->action(Akonadi::StandardActionManager::DeleteCollections)->setWhatsThis(
                 i18n("Delete the selected calendar folders from the calendar."));
             mGenericManager->setContextText(
@@ -113,14 +100,14 @@ public:
             break;
         case Akonadi::StandardActionManager::SynchronizeCollections:
             mGenericManager->setActionText(Akonadi::StandardActionManager::SynchronizeCollections,
-                                           ki18np("Update Calendar Folder", "Update %1 Calendar Folders"));
+                                           ki18np("Update Folder", "Update %1 Folders"));
             mGenericManager->action(Akonadi::StandardActionManager::SynchronizeCollections)->setWhatsThis(
                 i18n("Update the content of the selected calendar folders."));
 
             break;
         case Akonadi::StandardActionManager::CutCollections:
             mGenericManager->setActionText(Akonadi::StandardActionManager::CutCollections,
-                                           ki18np("Cut Calendar Folder", "Cut %1 Calendar Folders"));
+                                           ki18np("Cut Folder", "Cut %1 Folders"));
             mGenericManager->action(Akonadi::StandardActionManager::CutCollections)->setWhatsThis(
                 i18n("Cut the selected calendar folders from the calendar."));
             break;
@@ -499,7 +486,7 @@ public:
             }
         }
 
-        emit mParent->actionStateUpdated();
+        Q_EMIT mParent->actionStateUpdated();
     }
 
     void slotCreateEvent()
